@@ -18,7 +18,7 @@ class Patterns(CollectionApi):
     remove_method   = 'remove_pattern'
     nullable_edits   = [ 'scale ']
 
-    def add(self, name, slots:list=None, rate=1, direction='forward', length=None, mod_expressions_callback=None):
+    def add(self, name, slots:list=None, rate=1, direction='forward', length=None):
         params = locals()
         return self._generic_add(name, params)
 
