@@ -90,6 +90,14 @@ class Chord(object):
     def with_length_mod(self, mod):
         return self.with_notes([x.with_length_mod(mod) for x in self.notes])
 
+    def tie_count(self):
+        if len(self.notes):
+            return self.notes[0].tie_count()
+        return 0
+
+    def with_tied(self, amount):
+        return self.with_notes([x.with_tied(amount) for x in self.notes])
+
     def with_delay(self, delay):
         return self.with_notes([x.with_delay(mod) for x in self.notes])
 
@@ -143,3 +151,6 @@ class Chord(object):
 
     def get_notes(self):
         return self.notes
+
+    def __repr__(self):
+        return "Chord [%s]" % (",".join(str(x) for x in self.notes))
