@@ -148,6 +148,38 @@ class Clip(NewReferenceObject):
             start = start + slot_duration
         return start
 
+    # ==================================================================================================================
+
+    def _process_ties(self, chords):
+
+        previous_was_tie = False
+        previous_chord = None
+        tied = 0
+
+        for (i, slot) in enumerate(chords):
+
+            if i == 0 and (slot and len(slot.notes) and not slot.notes[0].tie):
+                previous_chord = slot
+
+            is_tie = False
+            if slot and len(slot.notes) and slot.notes[0].tie:
+                is_tie = True
+
+            if is_tie:
+                tied = tied + 1
+
+            if not is_tie:
+                if previous_was_tie:
+                    previous_chord.with_tied(previous_chord.notes[0].length * tied)
+                tied = 0
+
+            previous_was_tie = is_tie
+
+            if slot and len(slot.notes) and not slot.notes[0].tie:
+                previous_chord = slot
+
+
+
     # ==================================================================================================================
 
     def _notes_to_events(self, chords):
@@ -155,16 +187,19 @@ class Clip(NewReferenceObject):
         # processing tie events along the way and also delay metadata
 
         events = []
-        previous_chord = None
 
         for slot in chords:
 
             if not slot:
                 continue
-            elif len(slot.notes) and not slot.notes[0].tie:
-                previous_chord = slot
+
+            if len(slot.notes) and not slot.notes[0].tie:
+
+                tie_bonus = slot.tie_count()
+
                 for note in slot.notes:
-                    if note is not None and not note.tie:
+
+                    if note is not None and not note.tie and not note.muted:
 
                         if note.length_mod != 1:
                             note.length = (note.length_mod * note.length)
@@ -176,6 +211,8 @@ class Clip(NewReferenceObject):
                             note.end_time = note.end_time + bump
 
                         if not note.repeat:
+                            note.length = note.length + tie_bonus
+                            note.end_time = note.end_time + tie_bonus
                             event1 = Event(type=NOTE_ON, note=note,time=int(note.start_time))
                             events.append(event1)
                         else:
@@ -185,18 +222,14 @@ class Clip(NewReferenceObject):
                                 n1.length = delta
                                 n1.start_time = note.start_time + (x*delta)
                                 n1.end_time = n1.start_time + delta
-                                event2 = Event(type=NOTE_ON, note=note, time=int(n1.start_time))
+                                if x == note.repeat:
+                                    n1.length = n1.length + tie_bonus
+                                    n1.end_time = n1.end_time + tie_bonus
+                                event2 = Event(type=NOTE_ON, note=n1, time=int(n1.start_time))
                                 events.append(event2)
 
 
 
-            elif slot.notes[0].tie:
-                # extend time of previous notes by the length of the tie
-                tie_length = slot.notes[0].length
-                for p in previous_chord.notes:
-                    p.length = p.length + tie_length
-                    p.end_time = p.end_time + tie_length
-
         return events
 
     # ==================================================================================================================
@@ -261,24 +294,20 @@ class Clip(NewReferenceObject):
         """
 
         t_start = 0
-        #t1 = time.perf_counter()
-        results = []
+        chords_out = []
 
         for pattern in self.patterns:
 
             # get all the chords for each step
             chords = self._get_pattern_chord_list(song, t_start, pattern)
-
-            results.extend(chords)
+            chords_out.extend(chords)
             t_start = t_start + (self.slot_duration(song, pattern) * pattern.get_length())
 
         # convert to events
-        res = self._notes_to_events(results)
+        self._process_ties(chords_out)
+        return self._notes_to_events(chords_out)
 
-        #t2 = time.perf_counter()
-        #print(t2-t1)
 
-        return res
 
     # ==================================================================================================================
 
@@ -290,3 +319,5 @@ class Clip(NewReferenceObject):
         )
         player.engine.player = player
         return player
+
+
