@@ -27,7 +27,10 @@ class Probability(Evaluator):
         self.b = b
 
     def evaluate(self, context=None, subject=None):
-        if random.random() < self.chance:
+
+        chance = evaluate(self.chance, context, subject)
+
+        if random.random() < chance:
             return evaluate(self.a, context, subject)
         else:
             return evaluate(self.b, context, subject)
@@ -78,10 +81,8 @@ class DataGrab(Evaluator):
     def evaluate(self, context=None, subject=None):
         pool = context.song.find_data_pool_by_name(self.pool)
         if pool is None:
-            print("no such data pool: %s" % self.pool)
             return None
         data_slot = pool.get_next()
-        print(type(data_slot))
         value = data_slot.value
         res = evaluate(value, context, subject)
         return res
