@@ -116,6 +116,14 @@ class Note(object):
         n1.from_scale = scale_obj
         return n1
 
+    def tie_count(self):
+        # how many milliseconds should we add from ties marked after this note?
+        return self.tied
+
+    def with_tied(self, amount):
+        self.tied = amount
+        return self
+
     def shiftable(self):
         return not self.no_shift
 
@@ -215,18 +223,18 @@ class Note(object):
         return n1
 
     def __repr__(self):
+        if self.tie:
+            return "n<TIE>"
+        elif self.muted:
+            return "n<MUTED>"
         # FIXME: this will be simplified once we are doing less note debugging
-        return "Note<%s|%s,len=%s,time=%s/%s,cc=%s,tie=%s,muted=%s,track_copy=%s,def=%s>" % (
+        return "n<%s|%s,len=%s,time=%s/%s,cc=%s>" % (
             self.name,
             self.octave,
             self.length,
             self.start_time,
             self.end_time,
             self.ccs,
-            self.tie,
-            self.muted,
-            [x.name for x in self.track_copy],
-            self.deferred_expressions
         )
 
 
