@@ -46,8 +46,8 @@ class Slot(BaseSlot):
         "reverse", "reset", "tie", "degree_shift", "octave_shift" )
 
     def __init__(self, note=None, octave=None, octave_shift=None, degree_shift=None, degree=None, repeats=None, length=None, sharp=None, flat=None,
-                 chord_type=None, inversion=None, variables=None, track_copy=None, track_grab=None, rest=False, ccs=None,
-                 delay=None, velocity=None, skip=None, shuffle=None, reverse=None, reset=None, tie=None):
+                 chord_type=None, inversion=None, variables=None, track_copy=None, track_grab=None, ccs=None,
+                 delay=None, velocity=None, skip=None, shuffle=None, reverse=None, reset=None, tie=None, rest=None):
 
         self.note = note
         self.octave = octave
@@ -66,10 +66,10 @@ class Slot(BaseSlot):
         self.velocity = velocity
         self.skip = skip
         self.track_grab = track_grab
-        self.rest = rest
         self.shuffle = shuffle
         self.reverse = reverse
         self.reset = reset
+        self.rest = rest
         self.tie = tie
         self.degree_shift = degree_shift
         self.octave_shift = octave_shift
@@ -144,7 +144,7 @@ class Slot(BaseSlot):
         # NOTE RELATED OPS THAT DISCARD PITCH
 
         if evaluate(context=context, subject=note, how=self.tie):
-            return Note(tie=True)
+            return Note(tie=True, muted=True)
 
         if self.rest and evaluate(context=context, subject=note, how=self.rest):
             return None
