@@ -17,9 +17,11 @@ FORMAT_VERSION = 0.1
 
 class Song(NewReferenceObject):
 
-    __slots__ = [ 'name', 'clips', 'scale', 'tempo', 'devices', 'instruments', 'scales', 'scenes', 'tracks', 'transforms', 'patterns', 'obj_id' ]
+    __slots__ = [ 'name', 'clips', 'scale', 'tempo', 'devices', 'instruments', 'scales', 'scenes', 'tracks',
+                  'transforms', 'patterns', 'data_pools', 'obj_id' ]
 
-    def __init__(self, name=None, clips = None, scale=None, tempo=120, devices=None, instruments=None, scales=None, scenes=None, tracks=None, transforms=None, patterns=None, obj_id=None):
+    def __init__(self, name=None, clips = None, scale=None, tempo=120, devices=None, instruments=None, scales=None,
+                 scenes=None, tracks=None, transforms=None, patterns=None, data_pools=None, obj_id=None):
 
         self.name = name
         self.clips = clips
@@ -32,6 +34,7 @@ class Song(NewReferenceObject):
         self.tracks = tracks
         self.transforms = transforms
         self.patterns = patterns
+        self.data_pools = data_pools
         self.obj_id = obj_id
 
         super(Song, self).__init__()
@@ -55,6 +58,8 @@ class Song(NewReferenceObject):
             self.transforms = dict()
         if clear or self.patterns is None:
             self.patterns = dict()
+        if clear or self.data_pools is None:
+            self.data_pools = dict()
 
     def find_device(self, obj_id):
         """
@@ -127,12 +132,21 @@ class Song(NewReferenceObject):
         """
         return self.patterns.get(str(obj_id), None)
 
+    def find_data_pool(self, obj_id):
+        return self.data_pools.get(str(obj_id), None)
+
     def find_pattern_by_name(self, name):
         for (k,v) in self.patterns.items():
             if v.name == name:
                 return v
         return None
 
+    def find_data_pool_by_name(self, name):
+        for (k,v) in self.data_pools.items():
+            if v.name == name:
+                return v
+        return None
+
     def to_dict(self):
         """
         Returns the data for the entire song file.
@@ -152,6 +166,7 @@ class Song(NewReferenceObject):
             tracks = [ v.to_dict() for v in self.tracks ],
             transforms = { str(k) : v.to_dict() for (k, v) in self.transforms.items()},
             patterns = { str(k) : v.to_dict() for (k, v) in self.patterns.items()},
+            data_pools = {str(k): v.to_dict() for (k, v) in self.data_pools.items()},
             clips = { str(k) : v.to_dict() for (k,v) in self.clips.items() }
         )
         if self.scale:
@@ -194,6 +209,7 @@ class Song(NewReferenceObject):
         from . clip import Clip
         from . transform import Transform
         from . pattern import Pattern
+        from . data_pool import DataPool
 
         song.scales = { str(k) : Scale.from_dict(song, v) for (k,v) in data['scales'].items() }
         song.devices = { str(k) : Device.from_dict(song, v) for (k,v) in data['devices'].items() }
@@ -204,6 +220,8 @@ class Song(NewReferenceObject):
 
         song.transforms =  {str(k) : Transform.from_dict(song, v) for (k, v) in data['transforms'].items()}
         song.patterns =  { str(k) : Pattern.from_dict(song, v) for (k,v) in data['patterns'].items() }
+        song.data_pools =  { str(k) : DataPool.from_dict(song, v) for (k,v) in data['data_pools'].items() }
+
         song.clips =  { str(k) : Clip.from_dict(song, v) for (k,v) in data['clips'].items() }
 
         song.scale = song.find_scale(data['scale'])
@@ -392,6 +410,19 @@ class Song(NewReferenceObject):
         """
         del self.patterns[str(pattern.obj_id)]
 
+    def add_data_pools(self, data_pools):
+        """
+        Adds some pattern objects to the song.
+        """
+        for x in data_pools:
+            self.data_pools[str(x.obj_id)] = x
+
+    def remove_data_pool(self, data_pool):
+        """
+        Removes a pattern object from the song.
+        """
+        del self.data_pools[str(data_pool.obj_id)]
+
     def add_transforms(self, transforms):
         """
         Adds some transform objects to the song.
