@@ -56,16 +56,14 @@ class RealtimeEngine(object):
         # because the mod expression does throw away the note value and capture the value from
         # the guide track...
 
-        pattern = event.note.from_context.pattern
+        if event.note.muted:
+            return
 
         if event.type == NOTE_ON:
 
             # we have to process deferred expressions twice because of the mod events
             # UNLESS we pair the off event.
 
-            #self.context.scale = event.scale
-            #self.context.pattern = event.from_context.pattern
-
             exprs = event.note.deferred_expressions
             for expr in exprs:
                 value = expr.evaluate(self.track, event.note)
